@@ -36,7 +36,7 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.11.2_01'; # TRIAL VERSION
+our $VERSION = 'v0.11.2_02'; # TRIAL VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -399,7 +399,8 @@ sub configure {
         #   Files to include
         #
 
-        [ 'Manifest::Read' ],
+        [ 'Manifest::Read' ],   # REQUIRED VERSION: v0.5.0
+            # Colon-prefixed file finders (e. g. 'Manifest::Read/:AllFiles') are used.
 
         #
         #   Generated files
@@ -522,11 +523,11 @@ sub configure {
         [ 'Test::Portability' ],        # Checks filenames.
 
         [ 'Test::EOL' => {
-            'finder' => "$name/Manifest::Read",
+            'finder' => "$name/Manifest::Read/:AllFiles",
         } ],
 
         [ 'Test::NoTabs' => {
-            'finder' => "$name/Manifest::Read",
+            'finder' => "$name/Manifest::Read/:AllFiles",
         } ],
 
         [ 'MojibakeTests' ],
@@ -538,8 +539,8 @@ sub configure {
         } ],
 
         [ 'Test::Version' => {          # All modules have version.
-            finder    => "$name/Manifest::Read/InstallModules",
-                # REQUIRE: Dist::Zilla::Plugin::Manifest::Read v0.4.0 # want `/InstallModules`.
+            finder    => "$name/Manifest::Read/:InstallModules",
+                # REQUIRE: Dist::Zilla::Plugin::Manifest::Read v0.4.0 # want `/:InstallModules`.
             is_strict => 0,             # Strict version test fails in trial releases.
         } ],
 
@@ -944,7 +945,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.11.2_01, released on 2015-11-17 12:24 UTC.
+Version v0.11.2_02, released on 2016-11-23 22:52 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
@@ -1060,7 +1061,7 @@ __DATA__
 __[ not a real section, just a comment ]__
 
 #   `perldoc` interprets POD even after `__DATA__`, so module documentation will include all the
-#   sections below. To avoid this undesired behavour, prepend each POD directive with backslash â
+#   sections below. To avoid this undesired behavour, prepend each POD directive with backslash —
 #   it will be stripped by `Data::Section`.
 
 __[ doc/copying.pod ]__
@@ -1260,8 +1261,8 @@ To build a distribution from the source, run:
 
     $ dzil build
 
-If required C<Dist-Zilla> plugins are missed, C<dzil> tool will warn you and show the command to
-install all the required plugins, e. g.:
+If required C<Dist-Zilla> plugins are missed, the C<dzil> tool will warn you and show the command
+to install all the required plugins, e. g.:
 
     Required plugin Dist::Zilla::Plugin::Test::EOL isn't installed.
 
@@ -1270,13 +1271,14 @@ install all the required plugins, e. g.:
 
         dzil authordeps --missing | cpanm
 
-To run the tests:
+To run the tests (to check primary software functionality):
 
     $ dzil test
 
-To run all the tests, including release tests:
+To run extended tests (to check source code style, documentation and other things which are not too
+important for software end users):
 
-    $ dzil test --release
+    $ dzil xtest
 
 To install the distribution:
 
